@@ -1,4 +1,3 @@
-from django.contrib.auth import get_user_model
 from django.contrib.contenttypes.models import ContentType
 from django.urls import reverse
 
@@ -9,13 +8,13 @@ __all__ = (
     'admin_change_url'
 )
 
-User = get_user_model()
-
 
 def allowed_content_type(ct: ContentType) -> bool:
-    name = f'{ct.app_label}.{ct.model.title()}'
-    if name in LIKES_MODELS.keys():
+    name = f'{ct.app_label}.{ct.model.title()}'.lower()
+
+    if name in [item.lower() for item in LIKES_MODELS.keys()]:
         return True
+
     return False
 
 
@@ -25,6 +24,7 @@ def admin_change_url(obj) -> str:
     """
     app_label = obj._meta.app_label
     model_name = obj._meta.model.__name__.lower()
+
     return reverse(
         f'admin:{app_label}_{model_name}_change',
         args=(obj.pk,)
